/*
 * (C) Copyright IBM Corp. 1999  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */
package ui;
import org.xml.sax.InputSource;
import org.w3c.dom.Attr;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import com.ibm.xml.framework.ParserState;
import com.ibm.xml.framework.StringPool;
import com.ibm.xml.internal.MIME2Java;
import com.ibm.xml.parsers.DOMParser;

    /**
     *  The DOMParserSaveEncoding class extends DOMParser. It also provides
     *  the Java Encoding of the XML document by overriding the startDocument method 
     *  and providing a way to capture the MIME encoding from the XML document which
     *  in turn is converted to the Java Encoding by the internal MIME2Java class.
     *   
     */

  
public class DOMParserSaveEncoding extends DOMParser
  {
   String _mimeEncoding = "DEFAULT";//Default  MIME so we check the file.encoding
   private void setMimeEncoding( String encoding ) {
      _mimeEncoding = encoding;
   }
   private String getMimeEncoding() {
      return (_mimeEncoding);
   }
   public String getJavaEncoding() {
      String javaEncoding = null;
      String mimeEncoding = getMimeEncoding();

      if( mimeEncoding != null )
      {
      if( mimeEncoding.equals( "DEFAULT" ) )
         javaEncoding = System.getProperty( "file.encoding" );
      else if( ( javaEncoding = MIME2Java.convert( mimeEncoding ) ) == null )
         javaEncoding = "UTF8";      // We always return an encoding.
      }

      if( javaEncoding == null )  // Should never return null
         javaEncoding = "UTF8";

      return (javaEncoding);
   }
   public void startDocument( int versionIndex, int encodingIndex, int standAloneIndex ) {
      String encoding = null;
      if ( encodingIndex != -1 ) {
         ParserState state   = getParserState();
         StringPool  strPool = state.getStringPool();
         encoding            = strPool.toString( encodingIndex );
         setMimeEncoding( encoding );
      }
      super.startDocument( versionIndex,  encodingIndex, standAloneIndex );//passes control to superclass
   }

  }
    
